function [significance, postoji_D_L]= S_n (indeks, treshold, oznaka)
% S_n
% ulazi: indeks - indeks elementa matrice
%        treshold - prag 
%        oznaka - ako 1 -> raèuna se samo da li je taj element znaèajan
%                           (veæi od praga)
%                 ako 2 -> raèuna se znaèaj skupa svih descendant-a (potomaka)
%                 ako 3 -> raèuna se znaèaj skupa descendant-a osim djece
%                           (L)
% Izlaz: significance - znaèaj koeficijenta ili skupine koeficijenata (da
%                       li je veæi od praga)
%        postoji_D_L - zastavica koja oznaèava da li se došlo do ruba
%                      matrice, ako 0 -> taj koeficijent nema D ili L
%                      (ovisno o što je provjerava, tj koja je oznaka)


global wav_matrica

[x y]=size(indeks);
D= [];
ind_offsp = zeros (4,2);
postoji_D_L=1;
significance=0;
max_koef=0;

if oznaka==1 % predan korijen - njega izracunavamo

    if(abs(wav_matrica(indeks(1,1), indeks(1,2)))>= treshold)
        significance = 1;
    else
        significance = 0;
    end

elseif oznaka==2 % predan korijen - izracunavamo D-ove
    [D postoji_desc] = racunamo_descendante (indeks);
    if postoji_desc ==1
        max_koef = max(D); 
        if (abs (max_koef) >= treshold)
            significance = 1;
        else
            significance = 0; %svi u tom polju su insigificant
        end
    else
        postoji_D_L=0;
    end


elseif oznaka==3 %predan korijen - racunamo L-ove
    [L postoji_L] = racunamo_L (indeks);
    if postoji_L==1
        max_koef= max(L);
        if (abs (max_koef) >= treshold)
            significance = 1;
        else
            significance = 0;
        end
    else
        postoji_D_L=0;
    end
end


